Index: main/waeup.kofa/trunk/src/waeup/kofa/students/payments.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/payments.py	(revision 10028)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/payments.py	(revision 10030)
@@ -26,5 +26,5 @@
     IStudentPaymentsContainer, IStudentNavigation, IStudentOnlinePayment)
 from waeup.kofa.payments import PaymentsContainer, OnlinePayment
-from waeup.kofa.payments.interfaces import IPaymentWebservice
+from waeup.kofa.payments.interfaces import IPayer
 from waeup.kofa.utils.helpers import attrs_to_fields
 from waeup.kofa.accesscodes import create_accesscode
@@ -142,38 +142,38 @@
     StudentOnlinePayment, omit=['display_item'])
 
-class PaymentWebservice(grok.Adapter):
-    """An adapter to publish student data through a webservice.
+class Payer(grok.Adapter):
+    """An adapter to publish student data through a simple webservice.
     """
     grok.context(IStudentOnlinePayment)
-    grok.implements(IPaymentWebservice)
+    grok.implements(IPayer)
 
     @property
     def display_fullname(self):
-        "Name of  payee"
+        "Name of  payer"
         return self.context.student.display_fullname
 
     @property
     def id(self):
-        "Id of payee"
+        "Id of payer"
         return self.context.student.student_id
 
     @property
     def matric_number(self):
-        "Matric number or reg number of payee"
+        "Matric number or reg number of payer"
         return self.context.student.matric_number
 
     @property
     def reg_number(self):
-        "Reg number or reg number of payee"
+        "Reg number or reg number of payer"
         return self.context.student.reg_number
 
     @property
     def faculty(self):
-        "Faculty of payee"
+        "Faculty of payer"
         return self.context.student.faccode
 
     @property
     def department(self):
-        "Department of payee"
+        "Department of payer"
         return self.context.student.depcode
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_payment.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_payment.py	(revision 10028)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_payment.py	(revision 10030)
@@ -23,6 +23,6 @@
 from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
 from waeup.kofa.students.payments import (
-    StudentOnlinePayment, StudentOnlinePaymentFactory, PaymentWebservice)
-from waeup.kofa.payments.interfaces import IOnlinePayment, IPaymentWebservice
+    StudentOnlinePayment, StudentOnlinePaymentFactory, Payer)
+from waeup.kofa.payments.interfaces import IOnlinePayment, IPayer
 from waeup.kofa.students.interfaces import IStudentNavigation
 
@@ -49,4 +49,4 @@
         assert implemented_by.isOrExtends(IStudentNavigation)
 
-    def test_webservice_interface(self):
-        verify.verifyClass(IPaymentWebservice, PaymentWebservice)
+    def test_payer_interface(self):
+        verify.verifyClass(IPayer, Payer)

Index: main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_browser.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_browser.py	(revision 10028)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_browser.py	(revision 10030)
@@ -38,5 +38,5 @@
 from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
 from waeup.kofa.app import University
-from waeup.kofa.payments.interfaces import IPaymentWebservice
+from waeup.kofa.payments.interfaces import IPayer
 from waeup.kofa.students.interfaces import IStudentsUtils
 from waeup.kofa.students.student import Student
@@ -2313,10 +2313,10 @@
         self.assertEqual(self.student['payments'][value].p_level, 200)
 
-        # Student is the payee of the payment ticket.
-        webservice = IPaymentWebservice(self.student['payments'][value])
-        self.assertEqual(webservice.display_fullname, 'Anna Tester')
-        self.assertEqual(webservice.id, self.student_id)
-        self.assertEqual(webservice.faculty, 'fac1')
-        self.assertEqual(webservice.department, 'dep1')
+        # Student is the payer of the payment ticket.
+        payer = IPayer(self.student['payments'][value])
+        self.assertEqual(payer.display_fullname, 'Anna Tester')
+        self.assertEqual(payer.id, self.student_id)
+        self.assertEqual(payer.faculty, 'fac1')
+        self.assertEqual(payer.department, 'dep1')
 
         # We simulate the approval
@@ -2795,5 +2795,5 @@
 
 class PublicPagesTests(StudentsFullSetup):
-    # Tests for swebservices
+    # Tests for simple webservices
 
     layer = FunctionalLayer